@@ -1,4 +1,4 @@
-# $Id: Audio.pm,v 1.4 2002/11/01 16:12:43 joern Exp $
+# $Id: Audio.pm,v 1.5 2002/11/12 22:03:21 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -54,7 +54,7 @@ sub set_tc_bitrate {
 	my $self = shift;
 	my ($val) = @_;
 	my $audio_codec = $self->tc_audio_codec;
-	my $method = "st_tc_".$audio_codec."_bitrate";
+	my $method = "set_tc_".$audio_codec."_bitrate";
 	return $self->$method($val);
 }
 
